@@ -1,9 +1,6 @@
-# @(#)Ident: CPANDistributions.pm 2014-01-15 16:31 pjf ;
-
 package Module::Provision::TraitFor::CPANDistributions;
 
 use namespace::sweep;
-use version;  our $VERSION = qv( sprintf '0.31.%d', q$Rev: 2 $ =~ /\d+/gmx );
 
 use Class::Usul::Constants;
 use Class::Usul::Crypt::Util qw( decrypt_from_config encrypt_for_config
@@ -235,11 +232,6 @@ Module::Provision::TraitFor::CPANDistributions - Uploads/Deletes distributions t
    extends 'Module::Provision::Base';
    with    'Module::Provision::TraitFor::CPANDistributions';
 
-=head1 Version
-
-This documents version v0.31.$Rev: 2 $ of
-L<Module::Provision::TraitFor::CPANDistributions>
-
 =head1 Description
 
 Uploads/Deletes distributions to/from CPAN
